@@ -1,7 +1,7 @@
 #[derive(Debug, thiserror::Error)]
 pub(crate) enum Error {
-    #[error("failed to get tile at coordinate: ({0}, {1})")]
-    GetTile(u16, u16),
+    #[error("failed to get tile at coordinate: {0:?}")]
+    GetTile((usize, usize)),
 
     #[error("failed to draw to terminal")]
     DrawToTerminal(#[source] std::io::Error),
@@ -18,12 +18,6 @@ pub(crate) enum Error {
     #[error("failed to create terminal object")]
     CreateTerminal(#[source] std::io::Error),
 
-    #[error("failed to parse number from string: {1}")]
-    ParseNum(#[source] std::num::ParseIntError, String),
-
-    #[error("value must be greater than zero")]
-    GetNonZeroValue,
-
-    #[error("failed to convert u32 to usize")]
-    ConvertU32ToUsize(#[source] std::num::TryFromIntError),
+    #[error("failed to convert usize to u16")]
+    ConvertUsizeToU16(#[source] std::num::TryFromIntError),
 }
